//
//  XYCloudManager.m
//  xinhuamm_xycloud
//
//  Created by 邓付磊 on 2023/10/30.
//

#import "XYCloudManager.h"
#import <XYCMO2OModule/XYCMO2OModule.h>
#import <Bifrost/BifrostHeader.h>
#import <AFNetworking/AFNetworking.h>
#import "XinhuammXycloudPlugin.h"
#import <YYModel/YYModel.h>
@interface XYCloudManager() <XYO2OModuleServeDelegate>

@end

static AFHTTPSessionManager *_httpManager;

@implementation XYCloudManager

- (instancetype)init {
    if (self = [super init]) {
        _httpManager = [AFHTTPSessionManager manager];
        //设置请求超时时间
        _httpManager.requestSerializer.timeoutInterval = 30.f;
        //设置服务器返回结果的类型:JSON(AFJSONResponseSerializer,AFHTTPResponseSerializer)
        _httpManager.responseSerializer = [AFJSONResponseSerializer serializer];
        _httpManager.requestSerializer = [AFJSONRequestSerializer serializer];
        _httpManager.responseSerializer.acceptableContentTypes = [NSSet setWithObjects:@"application/json", @"text/html", @"text/json", @"text/plain", @"text/javascript", @"text/xml", @"image/*",@"multipart/form-data",@"application/x-www-form-urlencoded", nil];
        [_httpManager.requestSerializer setValue:@"application/json" forHTTPHeaderField:@"Accept"];
        [_httpManager.requestSerializer setValue:@"application/json" forHTTPHeaderField:@"Content-Type"];
        //开始监测网络状态
        [[AFNetworkReachabilityManager sharedManager] startMonitoring];
        
        [self initializeDefaultData];
    }
    return self;
}

#pragma mark- privite
/// 初始化默认数据
- (void)initializeDefaultData {
    /// 默认UA
    self.userAgent = @"xinhuamm DV/2";
    /// 微信支付scheme
    self.weixinSchemeUrl = @"yc.market.xinhuamm.net://";
    /// 支付宝支付Scheme
    self.appUrlScheme = [NSString stringWithFormat:@"yc.market.xinhuamm.net:%@://",[self configO2OALString]];
}


- (NSString *)configO2OALString {
    NSArray *arr = @[@"a", @"l", @"i", @"p", @"a", @"y"];
    return [arr componentsJoinedByString:@""];
}

#pragma mark -public

+ (instancetype)shareInstance {
    static XYCloudManager *instance = nil;
    static dispatch_once_t onceToken;
    dispatch_once(&onceToken, ^{
        instance = [[XYCloudManager alloc] init];
        [BFModule(XYO2OModuleService) configDeleage:instance];
    });
    return instance;
}

- (void)setUrl:(NSString *)url {
    _url = url;
    BFModule(XYO2OModuleService).o2oUrl = url;
}

- (void)setWeixinSchemeUrl:(NSString *)weixinSchemeUrl {
    _weixinSchemeUrl = weixinSchemeUrl;
    BFModule(XYO2OModuleService).weixinSchemeUrl = weixinSchemeUrl;
}

- (void)setAppUrlScheme:(NSString *)appUrlScheme {
    _appUrlScheme = appUrlScheme;
    BFModule(XYO2OModuleService).appUrlScheme = _appUrlScheme;
}

- (void)setUserId:(NSString *)userId {
    _userId = userId;
    BFModule(XYO2OModuleService).userId = userId;
}

- (void)setUserAgent:(NSString *)userAgent {
    _userAgent = userAgent ;
    BFModule(XYO2OModuleService).userAgent = userAgent;
}

- (void)setThemeColor:(NSString *)themeColor {
    _themeColor = themeColor;
    BFModule(XYO2OModuleService).themeColor = themeColor;
}

- (void)setNavigationColor:(NSString *)navigationColor {
    _navigationColor = navigationColor;
    BFModule(XYO2OModuleService).navigationColor = navigationColor;
}

- (void)setShowNavigationBar:(BOOL)showNavigationBar {
    _showNavigationBar = showNavigationBar;
    BFModule(XYO2OModuleService).showNavigationBar = showNavigationBar;
}

- (void)setO2oViewFrame:(CGRect)o2oViewFrame {
    _o2oViewFrame = o2oViewFrame;
    BFModule(XYO2OModuleService).o2oViewFrame = o2oViewFrame;
}

- (void)setAppUserToken:(NSString *)appUserToken {
    _appUserToken = appUserToken;
}

/// 是否登陆
- (BOOL)isLogin {
    return [XYCloudManager shareInstance].userId.length;
}

/// 清理用户
- (void)clearUser {
    self.url = nil;
    self.userId = nil;
}

- (void)enterO2OPageFromController:(UIViewController *)controller isPush:(BOOL)isPush {
    // 获取惠⽣活实例⻚⾯
    UIViewController *vc = [Bifrost handleURL:XYCMO2OPage complexParams:@{} completion:^(id _Nullable result) {
        
    }];
    if (!controller) {
        controller = [[UIApplication sharedApplication].delegate window].rootViewController;
    }
    if (isPush) {
        if (controller.navigationController) {
            [controller.navigationController pushViewController:vc animated:YES];
        } else {
            UINavigationController *nav = [[UINavigationController alloc] initWithRootViewController:vc];
            nav.modalPresentationStyle = UIModalPresentationFullScreen;
            [controller presentViewController:nav animated:YES completion:nil];
        }
    } else {
        UINavigationController *nav = [[UINavigationController alloc] initWithRootViewController:vc];
        nav.modalPresentationStyle = UIModalPresentationFullScreen;
        [controller presentViewController:nav animated:YES completion:nil];
    }
}


- (void)tryLoginWithUserId:(NSString *)userId completion:(void (^)(NSString *url))completion {
    [_httpManager POST:@"" parameters:@{} headers:@{} progress:^(NSProgress * _Nonnull uploadProgress) {
        
    } success:^(NSURLSessionDataTask * _Nonnull task, id  _Nullable responseObject) {
        completion ? completion(@"") : nil;
    } failure:^(NSURLSessionDataTask * _Nullable task, NSError * _Nonnull error) {
        completion ? completion(@"") : nil;
    }];
}

#pragma mark - XYO2OModuleServeDelegate

/// 公有云获取token - 替换免登逻辑 - 参考XYWebViewJSBridgeManager
- (void)getCloudTokenWith:(NSDictionary *)parameters block:(void(^)(NSDictionary *data))block {
    [[XinhuammXycloudPlugin shareInstance] getLoginParamWithArguments:nil result:^(id result) {
        if (!result)  return;
        XYCloudManager *model = [XYCloudManager yy_modelWithDictionary:result];
        if (!model.appUserToken.length) return;
        self.appUserToken = model.appUserToken;
        /// 测试数据
        NSMutableDictionary *data = [NSMutableDictionary dictionary];
        data[@"status"] = @"200";
        NSMutableDictionary *msg = [NSMutableDictionary dictionary];
        /// params 为token
        msg[@"params"] = model.appUserToken;
        data[@"msg"] = msg;
        block ? block(data) : nil;
    }];
}

/// 获取用户信息 
- (void)getUserInfoWith:(NSDictionary *)parameters block:(void(^)(NSDictionary *data))block {
    [[XinhuammXycloudPlugin shareInstance] getLoginParamWithArguments:nil result:^(id result) {
        if (!result)  return;
        XYCloudManager *model = [XYCloudManager yy_modelWithDictionary:result];
        self.userId = model.userId;
        self.phone = model.phone;
        /// 测试数据
        NSMutableDictionary *data = [NSMutableDictionary dictionary];
        data[@"id"] = model.userId;
        data[@"name"] = @"";
        data[@"avatar"] = @"";
        data[@"phone"] = model.phone;
        block ? block(data) : nil;
    }];
}

- (void)bindCurrentUserId:(void (^)(NSString * _Nonnull))userIdBlock {

//    if (userIdBlock) {
//        if (![[XYCloudManager shareInstance] isLogin]) {
//            userIdBlock(@"");
//        } else {
//            userIdBlock([XYCloudManager shareInstance].userId?:@"");
//        }
//    }
}



- (void)bindryLoginUrlWith:(NSString *)ryredirect application:(NSString *)application bindType:(BOOL)bindType ryLogin:(void (^)(NSString * _Nonnull, BOOL, NSString * _Nonnull))ryBlock {
    if (ryBlock) {
        ryBlock(@"", bindType, ryredirect);
    }
}


/// 分享
/// @param shareDic 分享参数：{"title":"标题", "description":"描述", "url":"链接",  "imageUrl":"分享图片",  "minPath":"小程序路径", "minId":"小程序id", "minType":2}
/// @param getPosterBlock 获取海报block，如果调用了 native 调用js 获取海报的方法
- (void)jsShareWithParameter:(NSDictionary *)shareDic getPosterBlock:(void (^)(BOOL))getPosterBlock {
    [[XinhuammXycloudPlugin shareInstance] shareWithArguments:shareDic result:nil];
}

@end
