#import "XinhuammXycloudPlugin.h"
#import "XYCloudManager.h"
#import <YYModel/YYModel.h>

/// 打开 Cloud page
NSString *const kOpenCloudPageMethodName = @"openCloudPage";
/// 全局配置
NSString *const kSetCloudGlobalConfigMethodName = @"setCloudGlobalConfig";
/// 用来判断用户是否登录/用户是否切换。返回："*"/""/null
NSString *const  kGetUserIdMethodName = @"getUserId";
/// 获取免登接口请求参数
NSString *const kGetLoginParamMethodName = @"getLoginParam";
/// 分享
NSString *const kShareMethodName = @"share";
///  打开微信小程序，call中带有小程序信息：code&path
NSString *const kOpenMiniMethodName = @"openMini";
///  登录
NSString *const kLoginMethodName = @"login";

@interface XinhuammXycloudPlugin()

///  通信相关类
@property (nonatomic, strong) FlutterMethodChannel* channel;

@end

@implementation XinhuammXycloudPlugin

+ (instancetype)shareInstance {
    static XinhuammXycloudPlugin *instance = nil;
    static dispatch_once_t onceToken;
    dispatch_once(&onceToken, ^{
        instance = [[XinhuammXycloudPlugin alloc] init];
    });
    return instance;
}

+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
    FlutterMethodChannel* channel = [FlutterMethodChannel
                                     methodChannelWithName:@"xinhuamm_xycloud"
                                     binaryMessenger:[registrar messenger]];
    XinhuammXycloudPlugin* instance = [XinhuammXycloudPlugin shareInstance];
    instance.channel = channel;
    [registrar addMethodCallDelegate:instance channel:channel];
}

/// 监听Flutter端调用原生端事件
/// - Parameters:
///   - call: flutter事件参数包含方法名 method、方法参数arguments
///   - result: flutter端回调
- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    if ([kSetCloudGlobalConfigMethodName isEqualToString:call.method]) {
        if ([call.arguments isKindOfClass:[NSDictionary class]]) {
            /// 全局配置
            NSDictionary *dict = call.arguments;
            XYCloudManager *model = [XYCloudManager yy_modelWithDictionary:dict];
            if (model.weixinSchemeUrl.length) {
                [XYCloudManager shareInstance].weixinSchemeUrl = model.weixinSchemeUrl;
            }
            if (model.appUrlScheme.length) {
                [XYCloudManager shareInstance].appUrlScheme = model.appUrlScheme;
            }
            if (model.themeColor.length) {
                [XYCloudManager shareInstance].themeColor = model.themeColor;
            }
            if (model.userAgent.length) {
                [XYCloudManager shareInstance].userAgent = model.userAgent;
            }
            [XYCloudManager shareInstance].showNavigationBar = model.showNavigationBar;
        }
        result([@"iOS " stringByAppendingString:call.method]);
    } if ([kOpenCloudPageMethodName isEqualToString:call.method]) {
        [XYCloudManager shareInstance].url = call.arguments;
        [[XYCloudManager shareInstance] enterO2OPageFromController:nil isPush:NO];

        result([@"iOS " stringByAppendingString:call.method]);
    } else if ([kGetUserIdMethodName isEqualToString:call.method]){
        result([@"iOS " stringByAppendingString:call.method]);
    }  else if ([kOpenMiniMethodName isEqualToString:call.method]){
        result([@"iOS " stringByAppendingString:call.method]);
    } else {
        result(FlutterMethodNotImplemented);
    }
}



///  原生端主动调用Flutter
/// - Parameters:
///   - method: 方法名
///   - arguments: 参数
///   - callback: 回调
- (void)invokeMethod:(NSString *)method arguments:(id)arguments result:(FlutterResult)callback {
    [self.channel invokeMethod:method arguments:arguments result:callback];
}

/// 获取免登接口请求参数
/// - Parameters:
///   - arguments: 参数
///   - callback: 回调结果
- (void)getLoginParamWithArguments:(id)arguments  result:(FlutterResult)callback {
    [self invokeMethod:kGetLoginParamMethodName arguments:arguments result:callback];
}

/// 分享
/// - Parameters:
///   - arguments: 参数
///   - callback: 回调结果
- (void)shareWithArguments:(id)arguments  result:(FlutterResult)callback {
    [self invokeMethod:kShareMethodName arguments:arguments result:callback];
}

/// 登录
/// - Parameters:
///   - arguments: 参数
///   - callback: 回调结果
- (void)loginWithArguments:(id)arguments  result:(FlutterResult)callback {
    [self invokeMethod:kLoginMethodName arguments:arguments result:callback];
}
@end
