//
//  XYO2OModuleService.h
//  O2O_iOS
//
//  Created by 唐海洋 on 2021/7/30.
//

#ifndef XYO2OModuleService_h
#define XYO2OModuleService_h
//#import "BifrostHeader.h"
#import <UIKit/UIKit.h>

NS_ASSUME_NONNULL_BEGIN

typedef void(^XYO2OWriteOffHandler)(NSDictionary *responseDic);

typedef void(^XYO2ORyloginHandler)(NSString *ryloginUrl);

#pragma mark - Notifications

#pragma mark - URL routers
/// O2O页面标识符
static NSString * const XYCMO2OPage = @"XYO2OViewController";

typedef enum : NSUInteger {
    XYO2OUrlType_unknown = 0,       // 未知类型
    XYO2OUrlType_O2O = 1,           // 惠生活
    XYO2OUrlType_INTEGRAL = 2,      // 积分商城
    XYO2OUrlType_RECRUITMENT = 3,   // 云招聘
    XYO2OUrlType_COMMUNITY = 4,     // 数字社区
    XYO2OUrlType_VENUES = 5,        // 云场馆
    XYO2OUrlType_activity = 6,      // 公有云活动
    XYO2OUrlType_writeOff = 7,      // 核销奖品
    XYO2OUrlType_driftBottle = 8,   // 漂流瓶
    XYO2OUrlType_standingsVerify = 9, // 积分商城核销
    XYO2OUrlType_signUpVerify = 10, // 报名核销
    XYO2OUrlType_eedsCommunity = 11, // 鄂尔多斯社区
    XYO2OUrlType_realEstate = 12, // 云房产
} XYO2OUrlType;

#pragma mark - Model Protocols


#pragma mark - Module Protocol
/**
 The services provided by XYO2OModuleService module to other modules
 */
@protocol XYO2OModuleService <NSObject>

//设置定位权限
//Privacy - Location Always and When In Use Usage Description   我们需要获取定位信息，用于计算当前位置与商家店铺之间的距离
//Privacy - Location When In Use Usage Description 我们需要获取定位信息，用于计算当前位置与商家店铺之间的距离
/// url
@property (nonatomic, copy)   NSString *o2oUrl;
/// 主题色：#f38242
@property (nonatomic, copy)   NSString *themeColor;
/// 导航背景色
@property (nonatomic, copy)   NSString *navigationColor;
/// UA标志符：xinhuamm
@property (nonatomic, copy)   NSString *userAgent;
/// 这个和微信支付回调的链接域名的有关系的： xyqm.market.platform.xinhuaapp.com
@property (nonatomic, copy)   NSString *weixinSchemeUrl;
/// app 私有协议
@property (nonatomic, copy)   NSString *appUrlScheme;
/// 登陆用户的id
@property (nonatomic, copy)   NSString *userId;
/// 允许外部设置O2OController页面的frame
@property (nonatomic, assign) CGRect o2oViewFrame;
/// 是否展示导航条，公有云需要展示o2o 不需要，默认 NO；
@property (nonatomic, assign) BOOL showNavigationBar;
/// 导航条显示与否交给 SDK 处理  默认为 sdk 处理
@property (nonatomic, assign) BOOL notAutoShowNavigationBar;
/// 网页加载的文件地址链接，进行特殊逻辑处理，例如：safari打开
@property (nonatomic, strong) NSArray *pathExtensions;
/// activityIds 活动id userId为key
@property (nonatomic, strong) NSDictionary *activityIds;
/// 是否展示loading
@property (nonatomic, assign) BOOL needShowLoading;

@optional

/// 设置代理并push的方式打开O2O页面
/// @param target id
- (void)showO2OWith:(id)target;

/// 设置代理
/// @param target id
- (void)configDeleage:(id)target;

//  预加载
- (void)preloadDatController:(UIViewController *)controller;

/// 获取 url 类型
/// @param urlString 需要判断的 url
- (XYO2OUrlType)getSDKUrlType:(NSString *)urlString;

/// 是否是 sdk 支持的 url 类型
/// @param urlString  url
- (BOOL)isSDKUrl:(NSString *)urlString;

/// 是否是 sdk 支持的扫码结果
/// @param codeString  code
- (BOOL)isSDKQRCodeString:(NSString *)codeString;

/// 根据扫码结果获取url  调用此接口前先判断是否是 sdk 支持的扫码结果
/// @param scanResult 扫码结果 string
- (NSString *)getUrlStringWithScanResult:(NSString *)scanResult;

#pragma mark - 核销奖品

/// 核销商品
/// @param result 扫码结果 调用此方法前请确保扫码结果是核销的二维码
/// @param phone 手机号  必传参数
/// @param completeBlock 核销结果回调
- (void)xyO2OWriteOffGoods:(NSString *)result phone:(NSString *)phone completeBlock:(XYO2OWriteOffHandler)completeBlock;

/// 积分商城
/// @param result 扫码结果 调用此方法前请确保扫码结果是核销的二维码
/// @param phone 手机号
/// @param type 核销类型 1积分商城核销 2报名核销
/// @param parameDic 其他参数 appkey appSecret
/// @param completeBlock 核销结果回调
- (void)xyO2OCommonVerify:(NSString *)result phone:(NSString *)phone withOtherParameDic:(NSDictionary *)parameDic completeBlock:(XYO2OWriteOffHandler)completeBlock;

#pragma mark - 免登接口

/// 免登处理
/// @param accountId accountId
/// @param sessionId sessionId
/// @param redirectUrl redirectUrl
/// @param ryloginHandler 免登成功的回调
- (void)xyO2ORylogin:(NSString *)accountId
           sessionId:(NSString *)sessionId
         redirectUrl:(NSString *)redirectUrl
      ryloginHandler:(XYO2ORyloginHandler)ryloginHandler;

#pragma mark - 公有云上报相关

/**
 * 上报公有云日志
 * @param eventCode 日志类型
 * @param userId 用户Id
 * @param appKey  公有云key
 * @param appsecret 公有云secret
 * @param newsId 稿件Id
 * @param hostUrl 接口域名
 * @param transferKey 加签密钥 【若没传，则默认：1234567812345678】
 * @note hostUrl 若没传，则默认：https://signapi.xinhuamm.net
 */
- (void)reportPublicCloudLogWith:(NSString *)eventCode
                          userId:(NSString *)userId
                          appKey:(NSString *)appKey
                       appsecret:(NSString *)appsecret
                          newsId:(NSString *)newsId
                         hostUrl:(NSString *)hostUrl
                     transferKey:(NSString *)transferKey;

/**
 * 清空活动不上报的日志
 * @param userId 用户Id
 */
- (void)pubCloudLogCleanNotAddLogWithUserId:(NSString *)userId activityId:(NSString *)activityId ;
/**
 * 添加活动Id
 * @param activityId 活动Id
 */
- (void)pubCloudLogAddActivityId:(NSString *)activityId WithUserId:(NSString *)userId;
/**
 * 清空活动Id
 * @param userId 用户Id
 */
- (void)pubCloudLogCleanActivityIdWithUserId:(NSString *)userId;

@end


@protocol XYO2OModuleServeDelegate <NSObject>

@required

#warning - 必须要实现 - 否则影响前端代码执行
/// 必须要实现 - 否则影响前端代码执行
/// 获取/绑定用户id
/// @param userIdBlock block
- (void)bindCurrentUserId:(void(^)(NSString *userId))userIdBlock;


@optional

/// 免登
/// @param ryredirect 免登参数
/// @param application 免登参数
/// @param bindType  YES--主动发起,回调回来会刷新页面,NO--h5 发起,回调不会主动刷新页面  bindType 为 YES是可自行决定是否进行免登操作
/// @param ryBlock : ryLoginUrl--免登后的 url, bindType -- SDK 传出的 bindType 直接返回无需处理,  ryredirect -- SDK 传出的 url,直接返回无需处理
- (void)bindryLoginUrlWith:(NSString *)ryredirect application:(NSString *)application bindType:(BOOL)bindType ryLogin:(void(^)(NSString *ryLoginUrl, BOOL bindType, NSString *ryredirect))ryBlock;


/// 公有云获取token - 替换免登逻辑 - 参考XYWebViewJSBridgeManager
- (void)getCloudTokenWith:(NSDictionary *)parameters block:(void(^)(NSDictionary *data))block;

/// 获取用户信息 - 参考XYWebViewJSBridgeManager
- (void)getUserInfoWith:(NSDictionary *)parameters block:(void(^)(NSDictionary *data))block;

/// 页面是否可以侧滑返回 - 通过webView canGoBack 确定
- (void)interactivePopDisabledWith:(BOOL)canGoBack;

/// 宣城钱包-订单支付
- (void)payOrderByWallet:(NSDictionary *)parameters;

/// 获取三方（秭归：nickname、userid、sign、nonce、sign）用户信息
/// @param completeBlock 完成回调
- (void)bindUserInfoWithComplete:(void(^)(NSDictionary *info))completeBlock;

/// 分享
/// @param shareDic 分享参数：{"title":"标题", "description":"描述", "url":"链接",  "imageUrl":"分享图片",  "minPath":"小程序路径", "minId":"小程序id", "minType":2}
/// @param getPosterBlock 获取海报block，如果调用了 native 调用js 获取海报的方法
- (void)jsShareWithParameter:(NSDictionary *)shareDic getPosterBlock:(void(^)(BOOL getPoter))getPosterBlock;

/// 生成海报
/// @param imageString 海报图片 base64 字符串
- (void)jsPosterWithImagestring:(NSString *)imageString;

/// 原生打开新页
/// @param dict 参数 map
- (void)jsOpenNewPage:(NSDictionary *)dict;

/// 打开兑吧积分商城
/// @param dict 参数 map
- (void)jsOpenDuiBaMallPage:(NSDictionary *)dict;

/// 签到任务，跳转客户端首⻚、指定频道(通过频道Id)
/// @param dict 参数 map
- (void)jsSignInTask:(NSDictionary *)dict;

/// 签到任务，跳转客户端首⻚、指定频道(通过频道code)、自定义频道
/// @param dict 参数 map
- (void)jsFinishTask:(NSDictionary *)dict;

/// 参与签到任务活动（通知客户端清理上报缓存）
/// @param dict 参数 map
- (void)jsJoinSignInTask:(NSDictionary *)dict;


@end


NS_ASSUME_NONNULL_END

#endif /* XYO2OModuleService_h */
